@@ -28,6 +28,15 @@ func readAllYaml(path string, t *testing.T) {
 	for _, m := range manifests {
 		contents := make(map[string]interface{})
 		t.Logf("Checking %s...", m.Name)
+
+		// drop Golang template directive on a complete line
+		lines := []string{}
+		for _, l := range strings.Split(string(m.Data), "\n") {
+			if !strings.HasPrefix(strings.TrimSpace(l), "${") && !strings.HasPrefix(strings.TrimSpace(l), "{{") {
+				lines = append(lines, l)
+			}
+		}
+
 		if err := yaml.Unmarshal(m.Data, &contents); err != nil {
 			t.Errorf("Unexpected error unmarshaling %s: %v", m.Name, err)
 		}
